Assorted spelling fixes.

Francois Gouget fgouget at free.fr
Mon May 4 03:50:31 CDT 2009


---
 dlls/comctl32/listview.c     |    2 +-
 dlls/riched20/tests/editor.c |    2 +-
 dlls/user32/tests/edit.c     |    4 ++--
 3 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/dlls/comctl32/listview.c b/dlls/comctl32/listview.c
index 967b867..14eaa23 100644
--- a/dlls/comctl32/listview.c
+++ b/dlls/comctl32/listview.c
@@ -9816,7 +9816,7 @@ static inline LRESULT LISTVIEW_GetVersion(LISTVIEW_INFO *infoPtr)
  * [I] iVersion : version to be set
  *
  * RETURN:
- * -1 when requested version is greater then DLL version;
+ * -1 when requested version is greater than DLL version;
  * previous version otherwise
  */
 static LRESULT LISTVIEW_SetVersion(LISTVIEW_INFO *infoPtr, DWORD iVersion)
diff --git a/dlls/riched20/tests/editor.c b/dlls/riched20/tests/editor.c
index bbad748..0383d14 100644
--- a/dlls/riched20/tests/editor.c
+++ b/dlls/riched20/tests/editor.c
@@ -3421,7 +3421,7 @@ static void test_EM_STREAMOUT_FONTTBL(void)
               brackCount--;
           fontTbl++;
       }
-    /* checks wether closing bracket is ok */
+    /* checks whether closing bracket is ok */
       ok(brackCount == 0, "missing closing bracket in \\fonttbl block\n");
       if(!brackCount)
       {
diff --git a/dlls/user32/tests/edit.c b/dlls/user32/tests/edit.c
index 8bcd634..399ec4c 100644
--- a/dlls/user32/tests/edit.c
+++ b/dlls/user32/tests/edit.c
@@ -1191,9 +1191,9 @@ static void test_edit_control_5(void)
               10, 10, 1, 1,
               NULL, NULL, NULL, NULL);
     assert(hWnd);
     /* size of non-child edit control is (much) bigger then requested */
     GetWindowRect( hWnd, &rc);
-    ok( rc.right - rc.left > 20, "size of the window (%d) is smaller then expected\n",
+    ok( rc.right - rc.left > 20, "size of the window (%d) is smaller than expected\n",
             rc.right - rc.left);
     DestroyWindow(hWnd);
     /* so create a parent, and give it edit controls children to test with */
@@ -1191,9 +1191,9 @@ static void test_edit_control_5(void)
               NULL, NULL, NULL, NULL);
     assert(hWnd);
-    /* size of non-child edit control is (much) bigger then requested */
+    /* size of non-child edit control is (much) bigger than requested */
     GetWindowRect( hWnd, &rc);
-- 
1.6.2.1



More information about the wine-patches mailing list